#!/usr/bin/env python

"""Package entry point."""


from stlearn.app import main


if __name__ == "__main__":  # pragma: no cover
    main()
